==> haskell-binary-orphans-0.1.8.0-85-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-orphans
version: 0.1.8.0
id: binary-orphans-0.1.8.0-IiLyqBm3n85VD9Ih781e
key: binary-orphans-0.1.8.0-IiLyqBm3n85VD9Ih781e
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-orphans#readme
synopsis: Orphan instances for binary
description:
    `binary-orphans` defines orphan instances for types in some popular packages.
category: Web
abi: 7fe4a38eb5b50eae08a00cdef612ff41
exposed: True
exposed-modules:
    Data.Binary.Orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/binary-orphans-0.1.8.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/binary-orphans-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/binary-orphans-0.1.8.0
hs-libraries: HSbinary-orphans-0.1.8.0-IiLyqBm3n85VD9Ih781e
depends:
    aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU base-4.12.0.0 binary-0.8.6.0
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    text-binary-0.2.1.1-96KOTVBvNf07QHlQtp73j1 time-1.8.0.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    vector-binary-instances-0.2.5.1-D99ZmWt6MS3AuLha13B1Ep
haddock-interfaces: /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock
haddock-html: /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-orphans-0.1.8.0-86-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-orphans
version: 0.1.8.0
id: binary-orphans-0.1.8.0-7dFGEWqk1cjKgSA9fLOuzi
key: binary-orphans-0.1.8.0-7dFGEWqk1cjKgSA9fLOuzi
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-orphans#readme
synopsis: Orphan instances for binary
description:
    `binary-orphans` defines orphan instances for types in some popular packages.
category: Web
abi: 847e9dc5ae819f243101b6559942aa9a
exposed: True
exposed-modules:
    Data.Binary.Orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/binary-orphans-0.1.8.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/binary-orphans-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/binary-orphans-0.1.8.0
hs-libraries: HSbinary-orphans-0.1.8.0-7dFGEWqk1cjKgSA9fLOuzi
depends:
    aeson-1.4.2.0-4xcoKSM2rCuFeYBdCYWLDU base-4.12.0.0 binary-0.8.6.0
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    text-binary-0.2.1.1-96KOTVBvNf07QHlQtp73j1 time-1.8.0.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    vector-binary-instances-0.2.5.1-D99ZmWt6MS3AuLha13B1Ep
haddock-interfaces: /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock
haddock-html: /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
